!**********************************************************************************  
! This computer software was prepared by Battelle Memorial Institute, hereinafter
! the Contractor, under Contract No. DE-AC05-76RL0 1830 with the Department of 
! Energy (DOE). NEITHER THE GOVERNMENT NOR THE CONTRACTOR MAKES ANY WARRANTY,
! EXPRESS OR IMPLIED, OR ASSUMES ANY LIABILITY FOR THE USE OF THIS SOFTWARE.
!
! MOSAIC module: see module_mosaic_driver.F for references and terms of use
!**********************************************************************************  

MODULE module_wetscav_driver


CONTAINS


!===========================================================================
!===========================================================================
      subroutine wetscav_driver (id,ktau,dtstep,ktauc,config_flags,        &
               dtstepc,alt,t_phy,moist,p8w,t8w,p_phy,chem,rho_phy,cldfra,  &
	       qlsink,precr,preci,precs,precg,                             &
	       gas_aqfrac, numgas_aqfrac,                                  &
	       h2oaj,h2oai,nu3,ac3,cor3,asulf,ahno3,anh3,cvaro1,           &
               cvaro2,cvalk1,cvole1,cvapi1,cvapi2,cvlim1,cvlim2,           &
               so4_wet_rm,no3_wet_rm,cl_wet_rm,nh4_wet_rm,                 &
               na_wet_rm,oin_wet_rm,oc_wet_rm,bc_wet_rm,                   &
               totoa_wet_rm,soa_wet_rm, dz8w,                              &
               ids,ide, jds,jde, kds,kde,                                  &
               ims,ime, jms,jme, kms,kme,                                  &
               its,ite, jts,jte, kts,kte                                   )

!----------------------------------------------------------------------
!
!  wet removal by grid-resolved precipitation
!  scavenging of cloud-phase aerosols and gases by collection, freezing, ...
!  scavenging of interstitial-phase aerosols by impaction
!  scavenging of gas-phase gases by mass transfer and reaction
!
!  This driver calls subroutines for wet scavenging.
!
!  1. MADE-SORGAM
!  2. MOSAIC
!
!----------------------------------------------------------------------

   USE module_configure
   USE module_state_description
   USE module_model_constants
! Adding module_data_mosaic_asect helps to access the lptr arrays
! Added by Manish Shrivastava on 04/21/2011
   USE module_data_mosaic_asect
   USE module_mosaic_wetscav, only:  wetscav_cbmz_mosaic
   USE module_aerosols_sorgam, only:  wetscav_sorgam_driver

   IMPLICIT NONE

!======================================================================
! Grid structure in physics part of WRF
!----------------------------------------------------------------------
! The horizontal velocities used in the physics are unstaggered
! relative to temperature/moisture variables. All predicted
! variables are carried at half levels except w, which is at full
! levels. Some arrays with names (*8w) are at w (full) levels.
!
!----------------------------------------------------------------------
! In WRF, kms (smallest number) is the bottom level and kme (largest
! number) is the top level.  In your scheme, if 1 is at the top level,
! then you have to reverse the order in the k direction.
!
!         kme      -   half level (no data at this level)
!         kme    ----- full level
!         kme-1    -   half level
!         kme-1  ----- full level
!         .
!         .
!         .
!         kms+2    -   half level
!         kms+2  ----- full level
!         kms+1    -   half level
!         kms+1  ----- full level
!         kms      -   half level
!         kms    ----- full level
!
!======================================================================
! Definitions
!-----------
!-- alt       inverse density
!-- t_phy	  temperature (K)
!-- w             vertical velocity (m/s)
!-- moist	  moisture array (4D - last index is species) (kg/kg)
!-- dz8w	  dz between full levels (m)
!-- p8w		  pressure at full levels (Pa)	
!-- p_phy	  pressure (Pa)
!                 points (dimensionless)
!-- z             3D height with lowest level being the terrain
!-- rho_phy   	  density (kg/m^3)
!-- qlsink        Fractional cloud water sink (/s)
!-- precr         rain precipitation rate at all levels (kg/m2/s)
!-- preci         ice precipitation rate at all levels (kg/m2/s)
!-- precs         snow precipitation rate at all levels (kg/m2/s)
!-- precg         graupel precipitation rate at all levels (kg/m2/s)                             &
!-- R_d		  gas constant for dry air ( 287. J/kg/K)
!-- R_v           gas constant for water vapor (461 J/k/kg)
!-- Cp            specific heat at constant pressure (1004 J/k/kg)
!-- rvovrd	  R_v divided by R_d (dimensionless)
!-- G		  acceleration due to gravity (m/s^2)
!-- ids           start index for i in domain
!-- ide           end index for i in domain
!-- jds           start index for j in domain
!-- jde           end index for j in domain
!-- kds           start index for k in domain
!-- kde           end index for k in domain
!-- ims           start index for i in memory
!-- ime           end index for i in memory
!-- jms           start index for j in memory
!-- jme           end index for j in memory
!-- kms           start index for k in memory
!-- kme           end index for k in memory
!-- its           start index for i in tile
!-- ite           end index for i in tile
!-- jts           start index for j in tile
!-- jte           end index for j in tile
!-- kts           start index for k in tile
!-- kte           end index for k in tile
!-- config_flags%kemit  end index for k for emissions arrays
!
!======================================================================

   TYPE(grid_config_rec_type),  INTENT(IN   )    :: config_flags

   INTEGER,      INTENT(IN   )    ::                                &
                                      ids,ide, jds,jde, kds,kde,    &
                                      ims,ime, jms,jme, kms,kme,    &
                                      its,ite, jts,jte, kts,kte,    &
                                      id, ktau, ktauc, numgas_aqfrac

      REAL,      INTENT(IN   ) :: dtstep,dtstepc
!
! moisture variables
!
   REAL, DIMENSION( ims:ime, kms:kme, jms:jme, num_moist ),         &
         INTENT(IN ) ::                                   moist
!
! all advected chemical species
!
   REAL, DIMENSION( ims:ime, kms:kme, jms:jme, num_chem ),          &
         INTENT(INOUT ) ::                                chem

! fraction of gas species in cloud water
   REAL, DIMENSION( ims:ime, kms:kme, jms:jme, numgas_aqfrac ),     &
         INTENT(IN ) ::                                   gas_aqfrac

!
! following are aerosol arrays that are not advected
!
   REAL, DIMENSION( ims:ime, kms:kme, jms:jme ),                    &
         INTENT(INOUT ) ::                                          &
           h2oaj,h2oai,nu3,ac3,cor3,asulf,ahno3,anh3,cvaro1,cvaro2, &
           cvalk1,cvole1,cvapi1,cvapi2,cvlim1,cvlim2
!
! input from meteorology
   REAL,  DIMENSION( ims:ime , kms:kme , jms:jme )         ,        &
          INTENT(IN   ) ::                                          &
                                                        alt,        &
                                                        dz8w,       &
                                                      t_phy,        &
                                                      p_phy,        &
                                                     t8w,p8w,       &
	                            qlsink,precr,preci,precs,precg, &
                                                    rho_phy,cldfra
!

! LOCAL  VAR
   integer :: ii,jj,kk,i,j,k,iphase,isize,itype
   REAL, DIMENSION( ims:ime, jms:jme, num_chem ) :: qsrflx ! column change due to scavening
   REAL ::  tmp_minval = 1.0e7

! Variables to calculate column integrated amounts removed by wet scavenging
! Added by Manish Shrivastava on 04/22/2011


! bf_scav represents values before call to wet scavenging
! af_scav represents values after call to wet scavenging

!Note for local variables do not specify intent
! Grid variable includes all state prognostic and diagnostic speices
!So these variables do not need to be defined
!just reference them as grid%so4_wet_rm for example
   REAL, DIMENSION( ims:ime, kms:kme, jms:jme) :: bf_scav_so4,bf_scav_no3,bf_scav_cl, &
                        bf_scav_nh4,bf_scav_na,bf_scav_oin, &
                        bf_scav_oc, bf_scav_bc,bf_scav_totoa,&
                        af_scav_so4,af_scav_no3,af_scav_cl, &
                        af_scav_nh4,af_scav_na,af_scav_oin, &
                        af_scav_oc, af_scav_bc,af_scav_totoa, &
                        bf_scav_soa,af_scav_soa

! Variables to hold aerosols removed by wet scavenging
! Added by Manish Shrivastav on 04/21/2011

   REAL, DIMENSION( ims:ime , jms:jme ),                       &
         INTENT(INOUT) :: so4_wet_rm, no3_wet_rm, cl_wet_rm, nh4_wet_rm, na_wet_rm,  &
                        oin_wet_rm, oc_wet_rm, bc_wet_rm, totoa_wet_rm,soa_wet_rm

   REAL, DIMENSION( ims:ime , jms:jme ) :: temp_bf_so4,temp_bf_no3,temp_bf_cl,temp_bf_nh4, &
                                           temp_bf_na,temp_bf_oin,temp_bf_oc,temp_bf_bc, &
                                           temp_bf_totoa,temp_bf_soa, &
                                           temp_af_so4,temp_af_no3,temp_af_cl,temp_af_nh4, &
                                           temp_af_na,temp_af_oin,temp_af_oc,temp_af_bc, &
                                           temp_af_totoa,temp_af_soa



!-----------------------------------------------------------------

! These are unneeded, since the default behavior is to do nothing.
! If the default changes, then lines need to be added for CBMZ and
! CBMZ_BB.
!   IF (config_flags%chem_opt .eq. 0) return
!   IF (config_flags%chem_opt .eq. 1) return

! First initialize local column burden arrays to zero
          do j=jts,jte
            do i=its,ite
            temp_bf_so4(i,j)=0.0
            temp_bf_no3(i,j)=0.0
            temp_bf_cl(i,j)=0.0
            temp_bf_nh4(i,j)=0.0
            temp_bf_na(i,j)=0.0
            temp_bf_oin(i,j)=0.0
            temp_bf_oc(i,j)=0.0
            temp_bf_bc(i,j)=0.0
            temp_bf_totoa(i,j)=0.0
            temp_bf_soa(i,j)=0.0


            temp_af_so4(i,j)=0.0
            temp_af_no3(i,j)=0.0
            temp_af_cl(i,j)=0.0
            temp_af_nh4(i,j)=0.0
            temp_af_na(i,j)=0.0
            temp_af_oin(i,j)=0.0
            temp_af_oc(i,j)=0.0
            temp_af_bc(i,j)=0.0
            temp_af_totoa(i,j)=0.0
            temp_af_soa(i,j)=0.0


            enddo
          enddo


    if (config_flags%chem_opt== SAPRC99_MOSAIC_4BIN_VBS2_AQ_KPP &
        .or. config_flags%chem_opt== SAPRC99_MOSAIC_8BIN_VBS2_AQ_KPP) then

! Get initial aerosol mixing ratios before wet deposition
              call temp_wet_dep_aer (id, ktau, chem,   &
                      ids,ide, jds,jde, kds,kde,   &
                      ims,ime, jms,jme, kms,kme,   &
                      its,ite, jts,jte, kts,kte,   &
                      bf_scav_so4,bf_scav_no3,bf_scav_cl, &
                      bf_scav_nh4,bf_scav_na,bf_scav_oin, &
                      bf_scav_oc, bf_scav_bc,bf_scav_totoa,&
                      bf_scav_soa         )

       
       endif


!
! select which aerosol scheme to take
!
   cps_select: SELECT CASE(config_flags%chem_opt)

   CASE ( RADM2SORG_AQ, RACMSORG_AQ, CBMZSORG_AQ )
       CALL wrf_debug(15,'wetscav_driver calling sorgam_wetscav_driver' )
       call wetscav_sorgam_driver (id,ktau,dtstep,ktauc,config_flags,      &
               dtstepc,alt,t_phy,p8w,t8w,p_phy,chem,rho_phy,cldfra,        &
               qlsink,precr,preci,precs,precg, qsrflx,                     &
               gas_aqfrac, numgas_aqfrac,                                  &
               ids,ide, jds,jde, kds,kde,                                  &
               ims,ime, jms,jme, kms,kme,                                  &
               its,ite, jts,jte, kts,kte                                   )
! not clear if the following is necessary or appropriate
       tmp_minval = 1.0e7
       do jj=jts,jte
       do kk=kts,kte
       do ii=its,ite
          if (chem(ii,kk,jj,p_nu0) .lt. tmp_minval) then
             chem(ii,kk,jj,p_nu0) = tmp_minval
          endif
       enddo
       enddo
       enddo

   CASE (CBMZ_MOSAIC_4BIN, CBMZ_MOSAIC_8BIN)
       CALL wrf_error_fatal('Wet scavenging is currently not possible with MOSAIC unless aqueous aerosols are turned on.')

   CASE (CBMZ_MOSAIC_4BIN_AQ, CBMZ_MOSAIC_8BIN_AQ, &
         CBMZ_MOSAIC_DMS_4BIN, CBMZ_MOSAIC_DMS_8BIN, CBMZ_MOSAIC_DMS_4BIN_AQ, CBMZ_MOSAIC_DMS_8BIN_AQ, &
         SAPRC99_MOSAIC_4BIN_VBS2_AQ_KPP,SAPRC99_MOSAIC_8BIN_VBS2_AQ_KPP )


       CALL wrf_debug(15,'wetscav_driver calling mosaic_wetscav_driver')
       call wetscav_cbmz_mosaic (id,ktau,dtstep,ktauc,config_flags,        &
               dtstepc,alt,t_phy,p8w,t8w,p_phy,chem,rho_phy,cldfra,        &
               qlsink,precr,preci,precs,precg, qsrflx,                     &
               gas_aqfrac, numgas_aqfrac,                                  &
               ids,ide, jds,jde, kds,kde,                                  &
               ims,ime, jms,jme, kms,kme,                                  &
               its,ite, jts,jte, kts,kte                                   )


   CASE DEFAULT

   END SELECT cps_select

    if (config_flags%chem_opt== SAPRC99_MOSAIC_4BIN_VBS2_AQ_KPP &
        .or.config_flags%chem_opt== SAPRC99_MOSAIC_8BIN_VBS2_AQ_KPP  ) then
!  Calulate aerosols after wet scavenging summed over interstitial and cloud borne

                  call temp_wet_dep_aer (id, ktau, chem,   &
                      ids,ide, jds,jde, kds,kde,   &
                      ims,ime, jms,jme, kms,kme,   &
                      its,ite, jts,jte, kts,kte,   &
                      af_scav_so4,af_scav_no3,af_scav_cl, &
                      af_scav_nh4,af_scav_na,af_scav_oin, &
                      af_scav_oc, af_scav_bc,af_scav_totoa,&
                      af_scav_soa         )




!  Note that so4_wet_rm, no3_wet_rm etc. arrays are initialized to 0 in chemics_init at first time step
!  These hold time integrated and column integrate amounts of total aerosols removed by wet scavening
!  Added by Manish Shrivastava on 04/21/2011

!  First calculate integrated column burdens before and after call to dry dep driver at each grid point
!  Coded by Manish Shrivastava on 05/12/2011

           do j=jts,jte
            do k=kts,kte
            do i=its,ite

                temp_bf_so4(i,j)=temp_bf_so4(i,j)+bf_scav_so4(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_no3(i,j)=temp_bf_no3(i,j)+bf_scav_no3(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_cl(i,j)=temp_bf_cl(i,j)+bf_scav_cl(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)


                temp_bf_nh4(i,j)=temp_bf_nh4(i,j)+bf_scav_nh4(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_na(i,j)=temp_bf_na(i,j)+bf_scav_na(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_oin(i,j)=temp_bf_oin(i,j)+bf_scav_oin(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_oc(i,j)=temp_bf_oc(i,j)+bf_scav_oc(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_bc(i,j)=temp_bf_bc(i,j)+bf_scav_bc(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_totoa(i,j)=temp_bf_totoa(i,j)+bf_scav_totoa(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_bf_soa(i,j)=temp_bf_soa(i,j)+bf_scav_soa(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_so4(i,j)=temp_af_so4(i,j)+af_scav_so4(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_no3(i,j)=temp_af_no3(i,j)+af_scav_no3(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_cl(i,j)=temp_af_cl(i,j)+af_scav_cl(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)


                temp_af_nh4(i,j)=temp_af_nh4(i,j)+af_scav_nh4(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_na(i,j)=temp_af_na(i,j)+af_scav_na(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_oin(i,j)=temp_af_oin(i,j)+af_scav_oin(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_oc(i,j)=temp_af_oc(i,j)+af_scav_oc(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_bc(i,j)=temp_af_bc(i,j)+af_scav_bc(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_totoa(i,j)=temp_af_totoa(i,j)+af_scav_totoa(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

                temp_af_soa(i,j)=temp_af_soa(i,j)+af_scav_soa(i,k,j) &
                                 /alt(i,k,j)*dz8w(i,k,j)

             enddo
            enddo
           enddo


!        Now calculated the amount removed by dry deposition at each grid point as difference of column burdens

           do j=jts,jte
            do i=its,ite
             so4_wet_rm(i,j)=so4_wet_rm(i,j)+(temp_af_so4(i,j)-temp_bf_so4(i,j))
             no3_wet_rm(i,j)=no3_wet_rm(i,j)+(temp_af_no3(i,j)-temp_bf_no3(i,j))
             cl_wet_rm(i,j)=cl_wet_rm(i,j)+(temp_af_cl(i,j)-temp_bf_cl(i,j))
             nh4_wet_rm(i,j)=nh4_wet_rm(i,j)+(temp_af_nh4(i,j)-temp_bf_nh4(i,j))
             na_wet_rm(i,j)=na_wet_rm(i,j)+(temp_af_na(i,j)-temp_bf_na(i,j))
             oin_wet_rm(i,j)=oin_wet_rm(i,j)+(temp_af_oin(i,j)-temp_bf_oin(i,j))
             oc_wet_rm(i,j)=oc_wet_rm(i,j)+(temp_af_oc(i,j)-temp_bf_oc(i,j))
             bc_wet_rm(i,j)=bc_wet_rm(i,j)+(temp_af_bc(i,j)-temp_bf_bc(i,j))
             totoa_wet_rm(i,j)=totoa_wet_rm(i,j)+(temp_af_totoa(i,j)-temp_bf_totoa(i,j))
             soa_wet_rm(i,j)=soa_wet_rm(i,j)+(temp_af_soa(i,j)-temp_bf_soa(i,j))

           enddo
           enddo



       endif


   end subroutine wetscav_driver

      subroutine temp_wet_dep_aer (id, ktau, chem,   &
                      ids,ide, jds,jde, kds,kde,   &
                      ims,ime, jms,jme, kms,kme,   &
                      its,ite, jts,jte, kts,kte,   &
                      temp_wet_so4,temp_wet_no3,temp_wet_cl, &
                      temp_wet_nh4,temp_wet_na,temp_wet_oin, &
                      temp_wet_oc, temp_wet_bc,temp_wet_totoa,&
                      temp_wet_soa         )

        use module_configure, only:  grid_config_rec_type, num_moist, num_chem
        use module_state_description, only:  param_first_scalar

        use module_data_mosaic_asect
        use module_data_mosaic_other

        IMPLICIT NONE

!   subr arguments
        integer, intent(in) ::   &
                id, ktau

        integer, intent(in) ::   &
                ids, ide, jds, jde, kds, kde,   &
                ims, ime, jms, jme, kms, kme,   &
                its, ite, jts, jte, kts, kte


        real, intent(inout),   &
                dimension( ims:ime, kms:kme, jms:jme, 1:num_chem ) :: &
                chem



   REAL, intent(inout), &
             DIMENSION( ims:ime, kms:kme, jms:jme)             &
                        :: temp_wet_so4,temp_wet_no3,temp_wet_cl, &
                        temp_wet_nh4,temp_wet_na,temp_wet_oin, &
                        temp_wet_oc, temp_wet_bc,temp_wet_totoa,&
                        temp_wet_soa

        integer i,j,k,isize,iphase,itype

!        First initialize local arrays to 0

          do j=jts,jte
           do k=kts,kte
            do i=its,ite
               temp_wet_so4(i,k,j)=0.0
               temp_wet_no3(i,k,j)=0.0
               temp_wet_cl(i,k,j)=0.0
               temp_wet_nh4(i,k,j)=0.0
               temp_wet_na(i,k,j)=0.0
               temp_wet_oin(i,k,j)=0.0
               temp_wet_oc(i,k,j)=0.0
               temp_wet_bc(i,k,j)=0.0
               temp_wet_totoa(i,k,j)=0.0
               temp_wet_soa(i,k,j)=0.0

           enddo
          enddo
         enddo


!   Now sum over interstial , cloud borne species and all size bins

      do iphase=1,nphase_aer
        do isize=1,ntype_aer
          do itype=1,ntype_aer
          do j=jts,jte
           do k=kts,kte
            do i=its,ite
             temp_wet_so4(i,k,j)=  temp_wet_so4(i,k,j) + &
                 chem(i,k,j,lptr_so4_aer(isize,itype,iphase))
             temp_wet_no3(i,k,j)=  temp_wet_no3(i,k,j) + &
                 chem(i,k,j,lptr_no3_aer(isize,itype,iphase))
             temp_wet_cl(i,k,j)=  temp_wet_cl(i,k,j) + &
                 chem(i,k,j,lptr_cl_aer(isize,itype,iphase))
             temp_wet_nh4(i,k,j)=  temp_wet_nh4(i,k,j) + &
                 chem(i,k,j,lptr_nh4_aer(isize,itype,iphase))
             temp_wet_na(i,k,j)=  temp_wet_na(i,k,j) + &
                 chem(i,k,j,lptr_na_aer(isize,itype,iphase))
             temp_wet_oin(i,k,j)=  temp_wet_oin(i,k,j) + &
                 chem(i,k,j,lptr_oin_aer(isize,itype,iphase))
             temp_wet_oc(i,k,j)=  temp_wet_oc(i,k,j) + &
                 chem(i,k,j,lptr_oc_aer(isize,itype,iphase))
             temp_wet_bc(i,k,j)=  temp_wet_bc(i,k,j) + &
                 chem(i,k,j,lptr_bc_aer(isize,itype,iphase))
             temp_wet_totoa(i,k,j)=  temp_wet_totoa(i,k,j) + &
                 chem(i,k,j,lptr_pcg1_b_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_pcg1_b_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_b_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_b_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_pcg1_f_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_pcg1_f_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_f_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_f_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_ant1_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_biog1_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_oc_aer(isize,itype,iphase))
             temp_wet_soa(i,k,j)=  temp_wet_soa(i,k,j) + &
                 chem(i,k,j,lptr_opcg1_b_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_b_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_f_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_opcg1_f_o_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_ant1_c_aer(isize,itype,iphase))+ &
                 chem(i,k,j,lptr_biog1_c_aer(isize,itype,iphase))



             enddo
            enddo
            enddo
            enddo
        enddo
       enddo

     end subroutine temp_wet_dep_aer


END MODULE module_wetscav_driver


